@@ -1,9 +1,9 @@
-# @(#)Ident: UpdatingContent.pm 2013-05-04 17:36 pjf ;
+# @(#)Ident: UpdatingContent.pm 2013-05-11 02:03 pjf ;
 
 package Module::Provision::TraitFor::UpdatingContent;
 
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.12.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.13.%d', q$Rev: 2 $ =~ /\d+/gmx );
 
 use Moose::Role;
 use Class::Usul::Constants;
@@ -40,6 +40,8 @@ sub update_version : method {
 
    $self->output( $self->loc( 'Updating version numbers' ) );
 
+   ($from, $to) = $self->update_version_pre_hook( $from, $to );
+
    for my $path (@{ $self->_get_manifest_paths }) {
       $ignore and $path =~ m{ (?: $ignore ) }mx and next;
       $self->substitute_version( $path, $from, $to );
@@ -52,6 +54,10 @@ sub update_version : method {
 sub update_version_post_hook { # Can be modified by applied traits
 }
 
+sub update_version_pre_hook { # Can be modified by applied traits
+   my $self = shift; return @_;
+}
+
 # Private methods
 sub _get_ignore_rev_regex {
    my $self = shift;
@@ -110,7 +116,7 @@ Module::Provision::TraitFor::UpdatingContent - Perform search and replace on pro
 
 =head1 Version
 
-This documents version v0.12.$Rev: 1 $ of L<Module::Provision::TraitFor::UpdatingContent>
+This documents version v0.13.$Rev: 2 $ of L<Module::Provision::TraitFor::UpdatingContent>
 
 =head1 Description
 
@@ -147,9 +153,15 @@ files in the F<MANIFEST>
 Substitutes the existing version number for the new version number in all
 files in the F<MANIFEST>
 
+=head2 update_version_pre_hook
+
+   $self->update_version_pre_hook;
+
+Returns it's input args by default. Can be modified by applied traits
+
 =head2 update_version_post_hook
 
-  $self->update_version_post_hook;
+   $self->update_version_post_hook;
 
 Does nothing by default. Can be modified by applied traits
 
